==> xshisen_1.51.orig.tar.gz: xshisen-1.51/lang/XShisen.ad.pl <==
! Common resources
XShisen*connectLineColor: blue
XShisen*connectLineTime: 1000
XShisen*aboutString: Shisen-sho dla X11 wersja XSHISEN_VERSION\n\n\
 Shisen-sho dla X11    autorstwa Masaoki Kobayashi <masaoki@techfirm.co.jp>\n\
   Shisen-sho dla Win  autorstwa Shinji Ono <ono@urban.ne.jp>\n\
   Grafika(kafle)      autorstwa Takayuki Akiyama <taco3@ybb.ne.jp>
XShisen*tedumari: Brak moliwoci wykonania ruchu.
XShisen*timeFormat: Czas Twojej gry wynis %2.2d:%2.2d.
XShisen*displayFormat1: Pozostao elementw: 
XShisen*displayFormat2: Czas: 
XShisen*score*scoreTitle: Najlepsze wyniki Shisen-sho\n\n
XShisen*score*strPeriod: W ostatnich %d dniach
XShisen*score*strPlayed: Rozegranych
XShisen*score*strCompleted: Ukoczonych
XShisen*score*strTedumari: Zablokowanych
XShisen*score*strSearched: Search used
XShisen*score*strGames: gier
XShisen*score*strAverage: rednio
XShisen*score*strTotal: Wszystkich
XShisen*score*strGiveUp: Poddanych
XShisen*score*personalTitle: Osobiste statystyki dla (%s)\n\n
XShisen*score*averagePeriod: 14

! Motif specific resources
XShisen*form.label0.foreground: #f0f0f0
XShisen*form.label1.foreground: #f0f0f0
XShisen*form.label2.foreground: #f0f0f0
XShisen*form.label3.foreground: #f0f0f0
XShisen*form.label0.background: #004000
XShisen*form.label1.background: #004000
XShisen*form.label2.background: #004000
XShisen*form.label3.background: #004000
XShisen*fontList: -*-fixed-medium-r-normal--16-*-iso8859-2
XShisen*drawing.foreground: #f0f0f0
XShisen*drawing.background: #004000
XShisen*score.dialogTitle: Rezultaty XShisen
XShisen*message.dialogTitle: XShisen
XShisen*mdialog.dialogTitle: Ostrzeenie
XShisen*mdialog.messageString: Nie mona zapisa pliku najlepszych wynikw.
XShisen*mdialog.okLabelString: Powtrz
XShisen*mdialog.cancelLabelString: Zaniechaj
XShisen*mb.button_0.labelString: Gra
XShisen*mb.button_0.mnemonic: G
XShisen*mb.button_1.labelString: Operacje
XShisen*mb.button_1.mnemonic: O
XShisen*mb.button_2.labelString: Konfiguracja
XShisen*mb.button_2.mnemonic: C
XShisen*mb.button_3.labelString: Picture
XShisen*mb.button_3.mnemonic: P
XShisen*pd0.button_0.labelString: Start
XShisen*pd0.button_0.mnemonic: D
XShisen*pd0.button_0.accelerator: Ctrl<Key>D
XShisen*pd0.button_0.acceleratorText: Ctrl-D
XShisen*pd0.button_1.labelString: Restartuj
XShisen*pd0.button_1.mnemonic: R
XShisen*pd0.button_1.accelerator: Ctrl<Key>R
XShisen*pd0.button_1.acceleratorText: Ctrl-R
XShisen*pd0.button_2.labelString: Pauza
XShisen*pd0.button_2.mnemonic: P
XShisen*pd0.button_2.accelerator: <Key>Escape
XShisen*pd0.button_2.acceleratorText: ESC
XShisen*pd0.button_3.labelString: Wyniki
XShisen*pd0.button_3.mnemonic: W
XShisen*pd0.button_3.accelerator: Ctrl<Key>S
XShisen*pd0.button_3.acceleratorText: Ctrl-S
XShisen*pd0.button_4.labelString: Wyniki osobiste
XShisen*pd0.button_4.mnemonic: T
XShisen*pd0.button_4.accelerator: Ctrl<Key>T
XShisen*pd0.button_4.acceleratorText: Ctrl-T
XShisen*pd0.button_5.labelString: O...
XShisen*pd0.button_5.mnemonic: O
XShisen*pd0.button_5.accelerator: Ctrl<Key>O
XShisen*pd0.button_5.acceleratorText: Ctrl-O
XShisen*pd0.button_6.labelString: Koniec
XShisen*pd0.button_6.mnemonic: k
!XShisen*pd0.button_6.accelerator: Ctrl<Key>X
!XShisen*pd0.button_6.acceleratorText: Ctrl-X
XShisen*pd1.button_0.labelString: Szukaj
XShisen*pd1.button_0.mnemonic: S
XShisen*pd1.button_0.accelerator: <Key>F1
XShisen*pd1.button_0.acceleratorText: F1
XShisen*pd1.button_1.labelString: Cofnij
XShisen*pd1.button_1.mnemonic: B
XShisen*pd1.button_1.accelerator: <Key>F5
XShisen*pd1.button_1.acceleratorText: F5
XShisen*pd2.button_0.labelString: Normalne   (18x 8)
XShisen*pd2.button_1.labelString: Due       (24x12)
XShisen*pd2.button_2.labelString: Ogromne    (36x16)
XShisen*pd2.button_3.labelString: Click Trial
XShisen*pd2.button_4.labelString: Grawitacja
XShisen*pd3.button_0.labelString: Picture#1
XShisen*pd3.button_1.labelString: Picture#2
XShisen*drawing.translations: #replace <Btn1Down>: PickupPiece()\n\
        <Btn2Down>(2): menu(0,0)\n\
        <Btn3Down>: CancelPiece()

!Athena Widget specific resources
XShisen*form.sform.label0.foreground: #f0f0f0
XShisen*form.sform.label1.foreground: #f0f0f0
XShisen*form.sform.label2.foreground: #f0f0f0
XShisen*form.sform.label3.foreground: #f0f0f0
XShisen*form.sform.label0.background: #004000
XShisen*form.sform.label1.background: #004000
XShisen*form.sform.label2.background: #004000
XShisen*form.sform.label3.background: #004000
XShisen*font: -*-fixed-medium-r-normal--16-*-iso8859-2
XShisen*fontSet: -*-fixed-medium-r-*--16-*-iso8859-2
!XShisen*international: True
XShisen*simple.foreground: #f0f0f0
XShisen*sform*background: #004000
XShisen*score.title: Rezultaty XShisen
XShisen*message.title: XShisen
XShisen*mdialog.title: Ostrzeenie
XShisen*mdialog.label.label: Nie mona zapisa pliku najlepszych wynikw.
XShisen*mdialog.ok_button.label: Powtrz
XShisen*mdialog.cancel_button.label: Zaniechaj
XShisen*mb.pd0.label: Gra
XShisen*mb.pd1.label: Operacje
XShisen*mb.pd2.label: Konfiguracja
XShisen*mb.pd3.label: Picture
XShisen*pd0*button_0.label: Start           Ctrl-D
XShisen*pd0*button_1.label: Restart         Ctrl-R
XShisen*pd0*button_2.label: Pauza           Ctrl-P
XShisen*pd0*button_3.label: Wyniki          Ctrl-S
XShisen*pd0*button_4.label: Wyniki osobiste Ctrl-T
XShisen*pd0*button_5.label: O...            Ctrl-A
XShisen*pd0*button_6.label: Koniec
XShisen*pd1*button_0.label: Szukaj    F1
XShisen*pd1*button_1.label: Cofnij    F5
XShisen*pd2*button_0.label: Normalne  (18x 8)
XShisen*pd2*button_1.label: Due      (24x12)
XShisen*pd2*button_2.label: Ogromne   (36x16)
XShisen*pd2*button_3.label: Click Trial
XShisen*pd2*button_4.label: Grawitacja
XShisen*pd3*button_0.label: Picture#1
XShisen*pd3*button_1.label: Picture#2
XShisen*sform*translations: #replace <Btn1Down>: PickupPiece()\n\
        <Btn2Down>(2): menu(0,0)\n\
        <Btn3Down>: CancelPiece()\n\
        Ctrl<Key>D: menu(0,0)\n\
        Ctrl<Key>R: menu(0,1)\n\
        <Key>Escape: menu(0,2)\n\
        Ctrl<Key>S: menu(0,3)\n\
        Ctrl<Key>T: menu(0,4)\n\
        Ctrl<Key>A: menu(0,5)\n\
        <Key>F1: menu(1,0)\n\
        <Key>F5: menu(1,1)

==> xshisen_1.51-1-1.tar.gz: xshisen-1.51/lang/XShisen.ad.pl <==
! Common resources
XShisen*connectLineColor: blue
XShisen*connectLineTime: 1000
XShisen*aboutString: Shisen-sho dla X11 wersja 1.50\n\n\
 Shisen-sho dla X11    autorstwa Masaoki Kobayashi <masaoki@techfirm.co.jp>\n\
   Shisen-sho dla Win  autorstwa Shinji Ono <ono@urban.ne.jp>\n\
   Grafika(kafle)      autorstwa Takayuki Akiyama <taco3@ybb.ne.jp>
XShisen*tedumari: Brak moliwoci wykonania ruchu.
XShisen*timeFormat: Czas Twojej gry wynis %2.2d:%2.2d.
XShisen*displayFormat1: Pozostao elementw: 
XShisen*displayFormat2: Czas: 
XShisen*score*scoreTitle: Najlepsze wyniki Shisen-sho\n\n
XShisen*score*strPeriod: W ostatnich %d dniach
XShisen*score*strPlayed: Rozegranych
XShisen*score*strCompleted: Ukoczonych
XShisen*score*strTedumari: Zablokowanych
XShisen*score*strSearched: Podpowiedzianych
XShisen*score*strGames: gier
XShisen*score*strAverage: rednio
XShisen*score*strTotal: Wszystkich
XShisen*score*strGiveUp: Poddanych
XShisen*score*personalTitle: Osobiste statystyki dla (%s)\n\n
XShisen*score*averagePeriod: 14

! Motif specific resources
XShisen*form.label0.foreground: #f0f0f0
XShisen*form.label1.foreground: #f0f0f0
XShisen*form.label2.foreground: #f0f0f0
XShisen*form.label3.foreground: #f0f0f0
XShisen*form.label0.background: #004000
XShisen*form.label1.background: #004000
XShisen*form.label2.background: #004000
XShisen*form.label3.background: #004000
XShisen*fontList: -*-fixed-medium-r-normal--16-*-iso8859-2
XShisen*drawing.foreground: #f0f0f0
XShisen*drawing.background: #004000
XShisen*score.dialogTitle: Rezultaty XShisen
XShisen*message.dialogTitle: XShisen
XShisen*mdialog.dialogTitle: Ostrzeenie
XShisen*mdialog.messageString: Nie mona zapisa pliku najlepszych wynikw.
XShisen*mdialog.okLabelString: Powtrz
XShisen*mdialog.cancelLabelString: Zaniechaj
XShisen*mb.button_0.labelString: Gra
XShisen*mb.button_0.mnemonic: G
XShisen*mb.button_1.labelString: Operacje
XShisen*mb.button_1.mnemonic: O
XShisen*mb.button_2.labelString: Konfiguracja
XShisen*mb.button_2.mnemonic: C
XShisen*mb.button_3.labelString: Kafle
XShisen*mb.button_3.mnemonic: P
XShisen*pd0.button_0.labelString: Start
XShisen*pd0.button_0.mnemonic: D
XShisen*pd0.button_0.accelerator: Ctrl<Key>D
XShisen*pd0.button_0.acceleratorText: Ctrl-D
XShisen*pd0.button_1.labelString: Restartuj
XShisen*pd0.button_1.mnemonic: R
XShisen*pd0.button_1.accelerator: Ctrl<Key>R
XShisen*pd0.button_1.acceleratorText: Ctrl-R
XShisen*pd0.button_2.labelString: Pauza
XShisen*pd0.button_2.mnemonic: P
XShisen*pd0.button_2.accelerator: <Key>Escape
XShisen*pd0.button_2.acceleratorText: ESC
XShisen*pd0.button_3.labelString: Wyniki
XShisen*pd0.button_3.mnemonic: W
XShisen*pd0.button_3.accelerator: Ctrl<Key>S
XShisen*pd0.button_3.acceleratorText: Ctrl-S
XShisen*pd0.button_4.labelString: Wyniki osobiste
XShisen*pd0.button_4.mnemonic: T
XShisen*pd0.button_4.accelerator: Ctrl<Key>T
XShisen*pd0.button_4.acceleratorText: Ctrl-T
XShisen*pd0.button_5.labelString: O...
XShisen*pd0.button_5.mnemonic: O
XShisen*pd0.button_5.accelerator: Ctrl<Key>O
XShisen*pd0.button_5.acceleratorText: Ctrl-O
XShisen*pd0.button_6.labelString: Koniec
XShisen*pd0.button_6.mnemonic: k
!XShisen*pd0.button_6.accelerator: Ctrl<Key>X
!XShisen*pd0.button_6.acceleratorText: Ctrl-X
XShisen*pd1.button_0.labelString: Szukaj
XShisen*pd1.button_0.mnemonic: S
XShisen*pd1.button_0.accelerator: <Key>F1
XShisen*pd1.button_0.acceleratorText: F1
XShisen*pd1.button_1.labelString: Cofnij
XShisen*pd1.button_1.mnemonic: B
XShisen*pd1.button_1.accelerator: <Key>F5
XShisen*pd1.button_1.acceleratorText: F5
XShisen*pd2.button_0.labelString: Normalne   (18x 8)
XShisen*pd2.button_1.labelString: Due       (24x12)
XShisen*pd2.button_2.labelString: Ogromne    (36x16)
XShisen*pd2.button_3.labelString: Szybkie klikanie
XShisen*pd2.button_4.labelString: Grawitacja
XShisen*pd3.button_0.labelString: Zestaw 1
XShisen*pd3.button_1.labelString: Zestaw 2
XShisen*drawing.translations: #replace <Btn1Down>: PickupPiece()\n\
        <Btn2Down>(2): menu(0,0)\n\
        <Btn3Down>: CancelPiece()

!Athena Widget specific resources
XShisen*form.sform.label0.foreground: #f0f0f0
XShisen*form.sform.label1.foreground: #f0f0f0
XShisen*form.sform.label2.foreground: #f0f0f0
XShisen*form.sform.label3.foreground: #f0f0f0
XShisen*form.sform.label0.background: #004000
XShisen*form.sform.label1.background: #004000
XShisen*form.sform.label2.background: #004000
XShisen*form.sform.label3.background: #004000
XShisen*font: -*-fixed-medium-r-normal--16-*-iso8859-2
XShisen*fontSet: -*-fixed-medium-r-*--16-*-iso8859-2
!XShisen*international: True
XShisen*simple.foreground: #f0f0f0
XShisen*sform*background: #004000
XShisen*score.title: Rezultaty XShisen
XShisen*message.title: XShisen
XShisen*mdialog.title: Ostrzeenie
XShisen*mdialog.label.label: Nie mona zapisa pliku najlepszych wynikw.
XShisen*mdialog.ok_button.label: Powtrz
XShisen*mdialog.cancel_button.label: Zaniechaj
XShisen*mb.pd0.label: Gra
XShisen*mb.pd1.label: Operacje
XShisen*mb.pd2.label: Konfiguracja
XShisen*mb.pd3.label: Kafle
XShisen*pd0*button_0.label: Start           Ctrl-D
XShisen*pd0*button_1.label: Restart         Ctrl-R
XShisen*pd0*button_2.label: Pauza           Ctrl-P
XShisen*pd0*button_3.label: Wyniki          Ctrl-S
XShisen*pd0*button_4.label: Wyniki osobiste Ctrl-T
XShisen*pd0*button_5.label: O...            Ctrl-A
XShisen*pd0*button_6.label: Koniec
XShisen*pd1*button_0.label: Szukaj    F1
XShisen*pd1*button_1.label: Cofnij    F5
XShisen*pd2*button_0.label: Normalne  (18x 8)
XShisen*pd2*button_1.label: Due      (24x12)
XShisen*pd2*button_2.label: Ogromne   (36x16)
XShisen*pd2*button_3.label: Szybkie klikanie
XShisen*pd2*button_4.label: Grawitacja
XShisen*pd3*button_0.label: Zestaw 1
XShisen*pd3*button_1.label: Zestaw 2
XShisen*sform*translations: #replace <Btn1Down>: PickupPiece()\n\
        <Btn2Down>(2): menu(0,0)\n\
        <Btn3Down>: CancelPiece()\n\
        Ctrl<Key>D: menu(0,0)\n\
        Ctrl<Key>R: menu(0,1)\n\
        <Key>Escape: menu(0,2)\n\
        Ctrl<Key>S: menu(0,3)\n\
        Ctrl<Key>T: menu(0,4)\n\
        Ctrl<Key>A: menu(0,5)\n\
        <Key>F1: menu(1,0)\n\
        <Key>F5: menu(1,1)
